[dpdk-dev] [PATCH v2 1/2] net/dpaa: fix max push mode queue

Shreyansh Jain shreyansh.jain at nxp.com
Wed May 9 11:49:43 CEST 2018


Split default and max push mode queues to 4 and 8, respectively.

Fixes: e6573771cdfb ("net/dpaa: integrate the support of push mode in PMD")
Cc: hemant.agrawal at nxp.com

Signed-off-by: Shreyansh Jain <shreyansh.jain at nxp.com>

---
 v2:
  - Removed stray internal tracking number from commit message

 drivers/net/dpaa/dpaa_ethdev.c | 9 +++++----
 1 file changed, 5 insertions(+), 4 deletions(-)

diff --git a/drivers/net/dpaa/dpaa_ethdev.c b/drivers/net/dpaa/dpaa_ethdev.c
index 6bf8c1590..88febe4d9 100644
--- a/drivers/net/dpaa/dpaa_ethdev.c
+++ b/drivers/net/dpaa/dpaa_ethdev.c
@@ -74,12 +74,13 @@ static uint64_t dev_tx_offloads_nodis =
 
 /* Keep track of whether QMAN and BMAN have been globally initialized */
 static int is_global_init;
 /* At present we only allow up to 4 push mode queues - as each of this queue
  * need dedicated portal and we are short of portals.
  */
-#define DPAA_MAX_PUSH_MODE_QUEUE       4
+#define DPAA_MAX_PUSH_MODE_QUEUE       8
+#define DPAA_DEFAULT_PUSH_MODE_QUEUE   4
 
-static int dpaa_push_mode_max_queue = DPAA_MAX_PUSH_MODE_QUEUE;
+static int dpaa_push_mode_max_queue = DPAA_DEFAULT_PUSH_MODE_QUEUE;
 static int dpaa_push_queue_idx; /* Queue index which are in push mode*/
 
 
@@ -74,12 +74,13 @@ static uint64_t dev_tx_offloads_nodis =
 /* Keep track of whether QMAN and BMAN have been globally initialized */
 static int is_global_init;
-/* At present we only allow up to 4 push mode queues - as each of this queue
- * need dedicated portal and we are short of portals.
+/* At present we only allow up to 4 push mode queues as default - as each of
+ * this queue need dedicated portal and we are short of portals.
  */
-- 
2.17.0



More information about the dev mailing list